@@ -39,6 +39,7 @@
 #' @importFrom utils "txtProgressBar"
 #' @importFrom utils "setTxtProgressBar"
 #' @importFrom utils "globalVariables"
+#' @importFrom tidyr "replace_na"
 #'
 #' @import stats
 #'
@@ -149,6 +150,8 @@ getCoins <-
     marketdata[, ccols] <-
       apply(marketdata[, ccols], 2, function(x)
         gsub("-", "0", x))
+    marketdata$volume <- marketdata$volume  %>% tidyr::replace_na(0) %>% as.numeric()
+    marketdata$market <-marketdata$market  %>% tidyr::replace_na(0) %>% as.numeric()
     marketdata[, cols] <-
       suppressWarnings(apply(marketdata[, cols], 2, function(x)
         as.numeric(x)))
@@ -156,6 +159,7 @@ getCoins <-
     marketdata$close_ratio <-
       (marketdata$close - marketdata$low) / (marketdata$high - marketdata$low)
     marketdata$close_ratio <- round(marketdata$close_ratio, 4)
+    marketdata$close_ratio <- marketdata$close_ratio %>% tidyr::replace_na(0) %>% as.numeric()
     marketdata$spread <- (marketdata$high - marketdata$low)
     marketdata$spread <- round(marketdata$spread, 2)
     results <-
